# Jira Marketplace App
### On this page
  * [Benefits](https://help.sap.com/docs/leanix/ea/jira-software-integration#benefits)
  * [Limitations](https://help.sap.com/docs/leanix/ea/jira-software-integration#limitations)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/jira-software-integration#prerequisites)
  * [Step 1: Install the SAP LeanIX for Jira App](https://help.sap.com/docs/leanix/ea/jira-software-integration#step-1:-install-the-sap-leanix-for-jira-app)
  * [Step 2: Configure the SAP LeanIX for Jira App](https://help.sap.com/docs/leanix/ea/jira-software-integration#step-2:-configure-the-sap-leanix-for-jira-app)
  * [Linking Jira Issues to SAP LeanIX Fact Sheets](https://help.sap.com/docs/leanix/ea/jira-software-integration#linking-jira-issues-to-sap-leanix-fact-sheets)
  * [Creating Synchronization Mappings](https://help.sap.com/docs/leanix/ea/jira-software-integration#creating-synchronization-mappings)
  * [Syncing Jira Issues with SAP LeanIX Fact Sheets](https://help.sap.com/docs/leanix/ea/jira-software-integration#syncing-jira-issues-with-sap-leanix-fact-sheets)


View all
Sync your Jira issues with your architecture data to enhance productivity and gain insight into ongoing enterprise architecture initiatives.
SAP LeanIX for Jira lets you link Jira issues to SAP LeanIX fact sheets. Once you set up the app, you can create and search fact sheets directly from Jira issues and monitor Jira issues from within SAP LeanIX. This makes it easy to keep track of ongoing initiatives and align on their progress.
**Note**
The app only supports Jira Cloud.
